@@ -4,16 +4,10 @@
 
 package Date::Language::Somali;
 
-use strict;
-use warnings;
-
 use Date::Language ();
-use base 'Date::Language';
-
-our $VERSION = '2.34_01'; # TRIAL VERSION: generated
-# ABSTRACT: Somali localization for Date::Format
-
-our (@DoW, @DoWs, @MoY, @MoYs, @AMPM, @Dsuf, %MoY, %DoW);
+use vars qw(@ISA @DoW @DoWs @MoY @MoYs @AMPM @Dsuf %MoY %DoW $VERSION);
+@ISA = qw(Date::Language);
+$VERSION = "0.99";
 
 @DoW = qw(Axad Isniin Salaaso Arbaco Khamiis Jimco Sabti);
 @MoY = (
@@ -51,7 +45,10 @@ our (@DoW, @DoWs, @MoY, @MoYs, @AMPM, @Dsuf, %MoY, %DoW);
 @Dsuf[11,12,13] = qw(th th th);
 @Dsuf[30,31] = qw(th st);
 
-Date::Language::_build_lookups();
+@MoY{@MoY}  = (0 .. scalar(@MoY));
+@MoY{@MoYs} = (0 .. scalar(@MoYs));
+@DoW{@DoW}  = (0 .. scalar(@DoW));
+@DoW{@DoWs} = (0 .. scalar(@DoWs));
 
 # Formatting routines
 
@@ -63,30 +60,3 @@ sub format_h { $MoYs[$_[0]->[4]] }
 sub format_p { $_[0]->[2] >= 12 ?  $AMPM[1] : $AMPM[0] }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Date::Language::Somali - Somali localization for Date::Format
-
-=head1 VERSION
-
-version 2.34_01
-
-=head1 AUTHOR
-
-Graham <gbarr@pobox.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by Graham Barr.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
